@@ -190,9 +190,8 @@ class _FlakyPlugin(object):
                     self._log_intermediate_failure(err, flaky_attributes, name)
                     self._mark_test_for_rerun(test)
                     return True
-                else:
-                    self._log_test_failure(name, err, self._not_rerun_message)
-                    return False
+                self._log_test_failure(name, err, self._not_rerun_message)
+                return False
             else:
                 flaky_attributes = self._get_flaky_attributes(test)
                 self._report_final_failure(err, flaky_attributes, name)
@@ -281,14 +280,14 @@ class _FlakyPlugin(object):
             if self._flaky_success_report:
                 self._stream.writelines([
                     ensure_unicode_string(name),
-                    ' passed {0} out of the required {1} times. '.format(
+                    ' passed {} out of the required {} times. '.format(
                         passes,
                         min_passes,
                     ),
                 ])
                 if need_reruns:
                     self._stream.write(
-                        'Running test again until it passes {0} times.\n'.format(
+                        'Running test again until it passes {} times.\n'.format(
                             min_passes,
                         )
                     )
@@ -351,7 +350,7 @@ class _FlakyPlugin(object):
             '--max-runs',
             action="store",
             dest="max_runs",
-            type="int",
+            type=int,
             default=2,
             help="If --force-flaky is specified, we will run each test at "
                  "most this many times (unless the test has its own flaky "
@@ -361,7 +360,7 @@ class _FlakyPlugin(object):
             '--min-passes',
             action="store",
             dest="min_passes",
-            type="int",
+            type=int,
             default=1,
             help="If --force-flaky is specified, we will run each test at "
                  "least this many times (unless the test has its own flaky "
@@ -507,12 +506,12 @@ class _FlakyPlugin(object):
         :rtype:
             `dict` of `unicode` to varies
         """
-        return dict((
-            (attr, cls._get_flaky_attribute(
+        return {
+            attr: cls._get_flaky_attribute(
                 test_item,
                 attr,
-            )) for attr in FlakyNames()
-        ))
+            ) for attr in FlakyNames()
+        }
 
     @classmethod
     def _add_flaky_test_failure(cls, test, err):
